import { isVue2, markRaw } from 'vue-demi';
import { createModuleLoader } from './core/moduleLoader';
import { createComponentLoader } from './core/componentLoader';
import { ModuleLoaderSymbol, setActiveLoader, setOptions, addErrorHandler, removeErrorHandler } from './register';
import { getUmdResolver } from './resolvers/umd';
/**
 * create module loader
 * @param resolver remote module resolver, default to umd resolver
 */
export function createLoader(resolver, container) {
    var _b;
    var _resolver = (_b = resolver === null || resolver === void 0 ? void 0 : resolver(container)) !== null && _b !== void 0 ? _b : getUmdResolver(container);
    var loader = markRaw({
        install: function (app) {
            // this allows calling registerSubModules() outside of a component setup after
            setActiveLoader(loader);
            if (!isVue2) {
                var moduleLoader = createModuleLoader(app, _resolver);
                var componentLoader = createComponentLoader(_resolver);
                loader._a = app;
                loader._moduleLoader = moduleLoader;
                loader._componentLoader = componentLoader;
                app.config.globalProperties.$moduleLoader = loader;
                app.provide(ModuleLoaderSymbol, loader);
            }
        },
        setOptions: function (options) {
            setOptions.call(null, options);
            return this;
        },
        addErrorHandler: function (handler) {
            addErrorHandler.call(null, handler);
            return this;
        },
        removeErrorHandler: function (handler) {
            removeErrorHandler.call(null, handler);
            return this;
        },
        resolver: Object.freeze(_resolver),
        // it's actually undefined here
        // @ts-expect-error set in install when using Vue 3
        _a: null,
        // @ts-expect-error set in install when using Vue 3
        _moduleLoader: null,
        // @ts-expect-error set in install when using Vue 3
        _componentLoader: null,
    });
    return loader;
}
